@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -33,6 +33,14 @@ G_BEGIN_DECLS
 #define GPM_IS_SCREENSAVER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GPM_TYPE_SCREENSAVER))
 #define GPM_SCREENSAVER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GPM_TYPE_SCREENSAVER, GpmScreensaverClass))
 
+#define GS_LISTENER_SERVICE	"org.gnome.ScreenSaver"
+#define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
+#define GS_LISTENER_INTERFACE	"org.gnome.ScreenSaver"
+
+#define GS_PREF_DIR		"/apps/gnome-screensaver"
+#define GS_PREF_LOCK_ENABLED	GS_PREF_DIR "/lock_enabled"
+#define GS_PREF_IDLE_DELAY	GS_PREF_DIR "/idle_delay"
+
 typedef struct GpmScreensaverPrivate GpmScreensaverPrivate;
 
 typedef struct
@@ -50,6 +58,8 @@ typedef struct
 					    		 gboolean	 connected);
 	void		(* auth_request)		(GpmScreensaver	*screensaver,
 					    		 gboolean	 auth);
+	void		(* idle_changed)		(GpmScreensaver	*screensaver,
+					    		 gboolean	 is_idle);
 } GpmScreensaverClass;
 
 GType		 gpm_screensaver_get_type		(void);
