@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -134,7 +134,7 @@ update_ac_throttle (GpmSrvScreensaver *srv_screensaver,
 
 static void
 update_lid_throttle (GpmSrvScreensaver *srv_screensaver,
-		     gboolean        lid_is_closed)
+		     gboolean           lid_is_closed)
 {
 	gboolean laptop_using_ext_mon;
 
@@ -213,14 +213,16 @@ dpms_mode_changed_cb (GpmDpms        *dpms,
  * Does the actions when the ac power source is inserted/removed.
  **/
 static void
-ac_adapter_changed_cb (GpmAcAdapter     *ac_adapter,
-		       GpmAcAdapterState state,
-		       GpmSrvScreensaver   *srv_screensaver)
+ac_adapter_changed_cb (GpmAcAdapter      *ac_adapter,
+		       GpmAcAdapterState  state,
+		       GpmSrvScreensaver *srv_screensaver)
 {
 	update_ac_throttle (srv_screensaver, state);
 
-	/* simulate user input, to fix #333525 */
-	gpm_screensaver_poke (srv_screensaver->priv->screensaver);
+	/* simulate user input, but only when the lid is open */
+	if (gpm_button_is_lid_closed (srv_screensaver->priv->button) == FALSE) {
+		gpm_screensaver_poke (srv_screensaver->priv->screensaver);
+	}
 }
 
 /**
